# coding: utf-8

"""
    Rapidata.Dataset

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from rapidata.api_client.models.get_validation_rapids_result import GetValidationRapidsResult
from typing import Optional, Set
from typing_extensions import Self

class GetValidationRapidsResultPagedResult(BaseModel):
    """
    GetValidationRapidsResultPagedResult
    """ # noqa: E501
    total: StrictInt
    page: StrictInt
    page_size: StrictInt = Field(alias="pageSize")
    items: List[GetValidationRapidsResult]
    total_pages: Optional[StrictInt] = Field(default=None, alias="totalPages")
    __properties: ClassVar[List[str]] = ["total", "page", "pageSize", "items", "totalPages"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetValidationRapidsResultPagedResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "total_pages",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetValidationRapidsResultPagedResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "total": obj.get("total"),
            "page": obj.get("page"),
            "pageSize": obj.get("pageSize"),
            "items": [GetValidationRapidsResult.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "totalPages": obj.get("totalPages")
        })
        return _obj





from __future__ import annotations
from rapidata.rapidata_client.datapoints._datapoint import Datapoint
from typing import TYPE_CHECKING, Optional

if TYPE_CHECKING:
    from rapidata.rapidata_client.dataset._rapidata_dataset import RapidataDataset
    from rapidata.rapidata_client.job.job_definition import JobDefinition
    from rapidata.rapidata_client.order.rapidata_order import RapidataOrder


class FailedUploadException(Exception):
    """Custom error class for Failed Uploads to the Rapidata order."""

    def __init__(
        self,
        dataset: RapidataDataset,
        failed_uploads: list[Datapoint],
        order: Optional[RapidataOrder] = None,
        job: Optional[JobDefinition] = None,
    ):
        self.dataset = dataset
        self.order = order
        self.job = job
        self.failed_uploads = failed_uploads

    def __str__(self) -> str:
        return f"Failed to upload {self.failed_uploads}"
